@@ -1,20 +1,20 @@
 #!/usr/bin/env python3
 
-'''
+"""
 test comment retrieval API
-'''
+"""
 
 import shutil
 import subprocess
 import sys
 
-if not shutil.which('murphi-comment-ls'):
-  print('murphi-comment-ls not found')
+if not shutil.which("murphi-comment-ls"):
+  print("murphi-comment-ls not found")
   sys.exit(125)
 
 
 # a model without any comments
-NONE = '''
+NONE = """
 var
   x: boolean;
 
@@ -25,10 +25,10 @@ end;
 rule begin
   x := !x;
 end;
-'''
+"""
 
 # a model with a single line comment
-SINGLE = '''
+SINGLE = """
 var
   x: boolean;
 
@@ -40,10 +40,10 @@ end;
 rule begin
   x := !x;
 end;
-'''
+"""
 
 # a model with a multiline comment
-MULTILINE = '''
+MULTILINE = """
 var
   x: boolean;
 
@@ -54,10 +54,10 @@ end;
 rule begin
   x := !x;
 end;
-'''
+"""
 
 # a model with a single line comment terminated by EOF, not \n
-SINGLE_EOF = '''
+SINGLE_EOF = """
 var
   x: boolean;
 
@@ -67,10 +67,10 @@ end;
 
 rule begin
   x := !x;
-end; -- hello world'''
+end; -- hello world"""
 
 # a model with a multiline comment terminated by EOF, not */
-MULTILINE_EOF = '''
+MULTILINE_EOF = """
 var
   x: boolean;
 
@@ -80,10 +80,10 @@ end;
 
 rule begin
   x := !x;
-end; /* hello world '''
+end; /* hello world """
 
 # comments inside strings that should be ignored
-STRING = '''
+STRING = """
 var
   x: boolean;
 
@@ -94,10 +94,10 @@ end;
 rule "hello /* world */" begin
   x := !x;
 end;
-'''
+"""
 
 # a model with a mixture
-MIX = '''
+MIX = """
 var
   x: boolean;
 
@@ -109,10 +109,10 @@ end; -- hello /* hello world */
 rule begin
   x := !x;
 end;
-'''
+"""
 
 def process(input):
-  proc = subprocess.Popen(['murphi-comment-ls'], stdin=subprocess.PIPE,
+  proc = subprocess.Popen(["murphi-comment-ls"], stdin=subprocess.PIPE,
     stdout=subprocess.PIPE, universal_newlines=True)
   stdout, _ = proc.communicate(input)
   assert proc.returncode == 0
@@ -120,22 +120,22 @@ def process(input):
 
 def main():
 
-  assert process(NONE) == ''
+  assert process(NONE) == ""
 
-  assert process(SINGLE) == '6.8-21:  hello world\n'
-  assert process(MULTILINE) == '6.8-24:  hello world \n'
+  assert process(SINGLE) == "6.8-21:  hello world\n"
+  assert process(MULTILINE) == "6.8-24:  hello world \n"
 
-  assert process(SINGLE_EOF) == '11.6-19:  hello world\n'
-  assert process(MULTILINE_EOF) == '11.6-20:  hello world \n'
+  assert process(SINGLE_EOF) == "11.6-19:  hello world\n"
+  assert process(MULTILINE_EOF) == "11.6-20:  hello world \n"
 
-  assert process(STRING) == ''
+  assert process(STRING) == ""
 
-  assert process(MIX) == '6.8-21:  hello world\n' \
-                         '7.3-19:  hello world \n' \
-                         '8.6-31:  hello /* hello world */\n' \
-                         '9.1-20:  hello -- hello \n'
+  assert process(MIX) == "6.8-21:  hello world\n" \
+                         "7.3-19:  hello world \n" \
+                         "8.6-31:  hello /* hello world */\n" \
+                         "9.1-20:  hello -- hello \n"
 
   return 0
 
-if __name__ == '__main__':
+if __name__ == "__main__":
   sys.exit(main())
